slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPGetST

Obtain the spectral transformation (ST) object associated to the eigensolver object.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPGetST(PEP pep,ST *st)

Not Collective

### Input Parameters

| pep | - eigensolver context obtained from PEPCreate()

### Output Parameter

| st | - spectral transformation context

### See Also

PEPSetST()

### Level

intermediate

### Location

src/pep/interface/pepbasic.c

### Examples

src/pep/tutorials/ex28.c.html
src/pep/tutorials/ex38.c.html
src/pep/tutorials/ex40.c.html
src/pep/tutorials/ex50.c.html
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages